##  Applying Views
Applying different views to the report allows for different perspectives and deeper analysis, akin to adding a third dimension for analysis. When applying a view, the color representation of the fact sheets changes. Therefore, it is good to apply the same field or tag group for the view that is assigned for the rings. This facilitates easier consumption of the report.
![Applying Views in Radar Report](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275690107a44101491349b5412a9a3b9_LowRes.png)
Applying Views in Radar Report
